summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--interpreter.c (renamed from debug.c)6
1 files changed, 4 insertions, 2 deletions
diff --git a/debug.c b/interpreter.c
index 4e0b270..0df27ce 100644
--- a/debug.c
+++ b/interpreter.c
@@ -1,10 +1,12 @@
/*
- * debug.c is a tool which can be used to interpret 6502 machine code inline.
+ * interpreter.c is a tool which can be used to interpret 6502 machine code inline.
* Machine code is expected as hexadecimal of length 2 or 6, depending on the instruction.
* Note that zero-page addressing is not fully emulated yet; it will still address the zero-page
section of memory but the instructions still take an address of length 4.
This will be fixed later when the whole system is functional.
- * There are a few special keywords which have particular debugging meaning
+ * There are a few special characters which print debug information
+ d Prints main system information
+ mXXXX Prints contents of particular memory location
*/
#include"include.h"